@@ -8,7 +8,11 @@ huge-merge.pl --keep test-A1
 sort ./test-A1/merge.* > ./test-A1/t0
 sort ./test-A1/test-A1.reqd > ./test-A1/t1
 
-diff ./test-A1/t0 ./test-A1/t1 > ./test-A1/var
+if ((-e ./test-A1/t0) && (-e ./test-A1/t1)) then 
+	diff ./test-A1/t0 ./test-A1/t1 > ./test-A1/var;
+else
+	echo "Test Error";
+endif
 
 if( -z ./test-A1/var ) then
 	echo "Test Ok";
